<?php
namespace Teknisa\COZ\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;
use Zeedhi\Framework\DTO\Response\Message;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\FilterCriteria;
use Zeedhi\Framework\DB\StoredProcedure\StoredProcedure;
use Zeedhi\Framework\DB\StoredProcedure\Param;

class CalculoCapacidadeProducao extends \Teknisa\GER\Controllers\TeknisaCrud
{

    protected $crudService;
    protected $entityManager;
    protected $util;

    public function __construct(
        $crudService, $parameterBag, $entityManager, $util
    )
    {
        parent::__construct($crudService, $parameterBag);
        $this->entityManager = $entityManager;
        $this->util = $util;
    }
    
    public function calculoCapacidade( DTO\Request\Row $request, DTO\Response $response){
       try{
            $row = $request->getRow();
            $connection = $this->entityManager->getConnection();
            $tempo = $this->converterHora($row['TEMPOTOTAL']);
            
            $procedureCalc = new \Zeedhi\Framework\DB\StoredProcedure\StoredProcedure($connection, 'CALC_CAPACIDADE_PROD_COZ');
            
            $procedureCalc->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDCENTRAL',        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['CDCENTRAL'],       \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_DTPRODDINI',      \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['DTINICIAL'],     \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_DTPRODFIN',           \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['DTFINAL'],                 \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_TEMPOPRODUCAO',         \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $tempo,        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NRPLANPROD',         \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['NRPLANPROD'],        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_NRORG',         \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['NRORG'],        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureCalc->addParam(new \Zeedhi\Framework\DB\StoredProcedure\Param('P_CDOPERADOR',         \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_INPUT, $row['CDOPERADOR'],        \Zeedhi\Framework\DB\StoredProcedure\Param::PARAM_TYPE_STR));
            $procedureCalc->execute();
        }catch(\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), 1));
        }
            
    }
    
    public function converterHora ($tempo){
        $hora = intval(substr($tempo,0,2));
        $minutos = intval(substr($tempo,3,2));
        return $tempoFloat = ($hora + ($minutos/60));
       
    }
    
    public function getDadosCapacidade( DTO\Request\Row $request, DTO\Response $response){
        $row = $request->getRow();
        $params = array(
            'NRPLANPROD'  => $row['NRPLANPROD'],
            'NRORG'       => $row['NRORG']
        );
        
        $sql = "SELECT CP.*, PP.HRINICIO FROM CAPACIDADEPRODCOZ CP 
                INNER JOIN PLANPRODACABADO PP ON PP.NRPLANPROD = CP.NRPLANPROD
                                                AND PP.CDPRODACABADO = CP.CDPRODUTO
                                                AND PP.NRSEQPRODACABADO = CP.NRSEQPRODACABADO
                                                AND PP.IDCOOKCHILL = CP.IDCOOKCHILL
                                                AND PP.IDFINALIZACAO = CP.IDFINALIZACAO
                                                AND PP.IDTPPRODCHILL = CP.IDTPPRODCHILL                                
                WHERE CP.NRPLANPROD = :NRPLANPROD AND CP.NRORG = :NRORG";
        $data = $this->entityManager->getConnection()->fetchAll($sql, $params);
        
        $response->addDataset(new DataSet('dados', $data));
    }
    

}